@@ -35,11 +35,11 @@
  **
  **/
 
-// $Id: EnrichmentMapParameters.java 525 2010-11-03 16:03:33Z risserlin $
-// $LastChangedDate: 2010-11-03 12:03:33 -0400 (Wed, 03 Nov 2010) $
-// $LastChangedRevision: 525 $
+// $Id: EnrichmentMapParameters.java 581 2011-07-06 15:47:03Z risserlin $
+// $LastChangedDate: 2011-07-06 11:47:03 -0400 (Wed, 06 Jul 2011) $
+// $LastChangedRevision: 581 $
 // $LastChangedBy: risserlin $
-// $HeadURL: svn+ssh://risserlin@server1.baderlab.med.utoronto.ca/svn/EnrichmentMap/trunk/EnrichmentMapPlugin/src/org/baderlab/csplugins/enrichmentmap/EnrichmentMapParameters.java $
+// $HeadURL: svn+ssh://server1.baderlab.med.utoronto.ca/svn/EnrichmentMap/trunk/EnrichmentMapPlugin/src/org/baderlab/csplugins/enrichmentmap/EnrichmentMapParameters.java $
 
 package org.baderlab.csplugins.enrichmentmap;
 import giny.model.Node;
@@ -61,12 +61,23 @@ import cytoscape.CytoscapeInit;
  */
 public class EnrichmentMapParameters {
 
-    private String NetworkName;
+    private String NetworkName = null;
     private String attributePrefix;
 
     //Input File names
     //GMT - gene set definition file
     private String GMTFileName;
+
+    //directory where the GMT and GCT(expression) files are found
+    //needed for Bulk EM creation when the user has moved their files
+    //around and they are not in the same directories that GSEA used.
+    private String GMTDirName = null;
+    private String GCTDirName = null;
+    private String GSEAResultsDirName = null;
+    private int lowerlimit = 1;
+    private int upperlimit = 1;
+
+
     //Expression files
     private String expressionFileName1;
     private String expressionFileName2;
@@ -102,9 +113,13 @@ public class EnrichmentMapParameters {
     private String method;
     //private boolean GSEA = true;
     //flag to indicate if the similarity cut off is jaccard or overlap
-    private boolean jaccard;
+    private String similarityMetric;
+
     private boolean similarityCutOffChanged = false;
 
+    //value to store the constant needed for constructing the combined similarity metric
+    private double combinedConstant;
+
     // DEFAULT VALUES for pvalue, qvalue, similarityCutOff and jaccard
     // will be assigned in the constructor
     //p-value cutoff
@@ -131,6 +146,12 @@ public class EnrichmentMapParameters {
     private HashSet<Integer> datasetGenes;
     private int NumberOfGenes = 0;
 
+    //only used when there are two distinct expression sets.
+    private HashSet<Integer> datasetGenes_set2;
+    private HashMap<String, GeneSet> filteredGenesets_set2;
+    private HashMap<String, GeneSet> genesets_set2;
+    private HashMap<String, GeneSet> genesetsOfInterest_set2;
+
     //In order to speed up union and intersections of nodes and edges in the network
     //store the genes that are present in the network.
     //get the intersection between the genes in the gene set file (gmt) and the genes in
@@ -161,6 +182,9 @@ public class EnrichmentMapParameters {
     private GeneExpressionMatrix expression;
     private GeneExpressionMatrix expression2;
 
+    //a flag to indicate if the two expression files have the exact same set of genes
+    private boolean twoDistinctExpressionSets = false;
+
     //default phenotype values.  These values can be set in the advanced features of
     //the input panel.
     private String dataset1Phenotype1 = "UP";
@@ -197,22 +221,35 @@ public class EnrichmentMapParameters {
     //the capability of storing more rank files
     private HashMap<String, HashMap<Integer, Ranking>> ranks;
 
+    //value specifying whether bulk EM is being used (needed to transfer file name to the network names)
+    private boolean BulkEM = false;
+
     private Properties cyto_prop;
     private double defaultPvalueCutOff;
     private double defaultQvalueCutOff;
     private double defaultJaccardCutOff;
     private double defaultOverlapCutOff;
+    private double defaultCombinedConstant;
     private String defaultSimilarityMetric;
     private Boolean disable_heatmap_autofocus;
     private String defaultSortMethod;
     private String defaultDistanceMetric;
 
+    //Constants
     final public static String ENRICHMENT_INTERACTION_TYPE = "Geneset_Overlap";
 
+    final public static String ENRICHMENT_INTERACTION_TYPE_SET1 = "Geneset_Overlap_set1";
+    final public static String ENRICHMENT_INTERACTION_TYPE_SET2 = "Geneset_Overlap_set2";
+
     //with more methods to support can't just have generic or gsea
     final public static String method_GSEA = "GSEA";
     final public static String method_generic = "generic";
-    final public static String method_DAVID = "DAVID";
+    final public static String method_DAVID = "DAVID/BiNGO";
+
+    //with more similarity metric can't use a boolean to reprensent them.
+    final public static String SM_JACCARD = "JACCARD";
+    final public static String SM_OVERLAP = "OVERLAP";
+    final public static String SM_COMBINED = "COMBINED";
 
     private PostAnalysisParameters paParams;
     
@@ -227,6 +264,9 @@ public class EnrichmentMapParameters {
         this.genes = new HashMap<String, Integer>();
         this.hashkey2gene = new HashMap<Integer, String>();
         this.datasetGenes = new HashSet<Integer>();
+        this.NetworkName = null;
+
+
 //        this.hashkey2bitindex = new HashMap<Integer, Integer>();
 //        this.bitindex2hashkey = new HashMap<Integer, Integer>();
         this.enrichmentMapGenes = new HashSet<Integer>();
@@ -252,13 +292,16 @@ public class EnrichmentMapParameters {
         this.defaultQvalueCutOff       = Double.parseDouble( this.cyto_prop.getProperty("EnrichmentMap.default_qvalue",  "0.1") );
         this.defaultJaccardCutOff      = Double.parseDouble( this.cyto_prop.getProperty("EnrichmentMap.default_jaccard", "0.25") );
         this.defaultOverlapCutOff      = Double.parseDouble( this.cyto_prop.getProperty("EnrichmentMap.default_overlap", "0.50") );
+        this.defaultCombinedConstant     = Double.parseDouble( this.cyto_prop.getProperty("EnrichmentMap.default_combinedConstant", "0.50") );
+
         this.defaultSimilarityMetric   = this.cyto_prop.getProperty("EnrichmentMap.default_similarity_metric",
                 this.cyto_prop.getProperty("EnrichmentMap.default_overlap_metric", "overlap")); // looking for Property "EnrichmentMap.default_overlap_metric" for legacy reasons
         this.disable_heatmap_autofocus = Boolean.parseBoolean( this.cyto_prop.getProperty("EnrichmentMap.disable_heatmap_autofocus", "false") );
 
         //get the default heatmap sort algorithm
         this.defaultSortMethod = this.cyto_prop.getProperty("EnrichmentMap.default_sort_method", HeatMapParameters.sort_hierarchical_cluster);
-
+        //get the default combined metric constant
+        this.combinedConstant = this.defaultCombinedConstant;
         //get the default distance metric algorithm
         this.defaultDistanceMetric = this.cyto_prop.getProperty("EnrichmentMap.default_distance_metric", HeatMapParameters.pearson_correlation);
 
@@ -272,17 +315,38 @@ public class EnrichmentMapParameters {
         qvalueSlider = new SliderBarPanel(0,this.qvalue,"Q-value Cutoff",this, EnrichmentMapVisualStyle.FDR_QVALUE_DATASET1, EnrichmentMapVisualStyle.FDR_QVALUE_DATASET2,ParametersPanel.summaryPanelWidth, false, this.qvalue);
 
         //choose Jaccard or Overlap as default
-        if ( getOverlapMetricDefault().equalsIgnoreCase("overlap") ){
+        if ( getOverlapMetricDefault().equalsIgnoreCase(SM_OVERLAP) ){
             this.similarityCutOff = this.defaultOverlapCutOff;
-            this.jaccard = false;
-        } else {
+            this.similarityMetric = SM_OVERLAP;
+        } else if( getOverlapMetricDefault().equalsIgnoreCase(SM_JACCARD)) {
             this.similarityCutOff = this.defaultJaccardCutOff;
-            this.jaccard = true;
+            this.similarityMetric = SM_JACCARD;
+        } else if( getOverlapMetricDefault().equalsIgnoreCase(SM_COMBINED)) {
+            this.similarityCutOff = this.defaultJaccardCutOff;
+            this.similarityMetric = SM_COMBINED;
         }
         this.enrichment_edge_type = ENRICHMENT_INTERACTION_TYPE;
 
         //create the slider for the similarity cutoff
         similaritySlider = new SliderBarPanel(this.similarityCutOff,1,"Similarity Cutoff",this, EnrichmentMapVisualStyle.SIMILARITY_COEFFECIENT, EnrichmentMapVisualStyle.SIMILARITY_COEFFECIENT,ParametersPanel.summaryPanelWidth, true, this.similarityCutOff);
+
+       //if there are two distinct expression sets we are going to need to instances of few of the variables
+        this.datasetGenes_set2 = new HashSet<Integer>();
+        this.genesets_set2 = new HashMap<String, GeneSet>();
+        this.filteredGenesets_set2 = new HashMap<String, GeneSet>();
+        this.genesetsOfInterest_set2 = new HashMap<String, GeneSet>();
+
+        //reset expression variables
+        this.expression = null;
+        this.expression2 = null;
+
+        //reset all boolean values
+        this.setFDR(false);
+        this.setData(false);
+        this.setData2(false);
+        this.setTwoDatasets(false);
+        this.setTwoDistinctExpressionSets(false);
+
     }
 
 
@@ -390,8 +454,24 @@ public class EnrichmentMapParameters {
         //boolean flags
         if((props.get("twoDatasets")).equalsIgnoreCase("true"))
             this.twoDatasets = true;
+        //first two take care of old session files that only had JAccard or overlap metrics
         if((props.get("jaccard")).equalsIgnoreCase("false"))
-            this.jaccard = false;
+            this.similarityMetric = SM_JACCARD;
+        else if((props.get("jaccard")).equalsIgnoreCase("true"))
+            this.similarityMetric = SM_OVERLAP;
+        else if ((props.get("jaccard")).equalsIgnoreCase(SM_JACCARD))
+            this.similarityMetric = SM_JACCARD;
+        else if ((props.get("jaccard")).equalsIgnoreCase(SM_OVERLAP))
+            this.similarityMetric = SM_OVERLAP;
+        else if ((props.get("jaccard")).equalsIgnoreCase(SM_COMBINED))
+            this.similarityMetric = SM_COMBINED;
+
+        //get the combined constant
+        if(props.get("CombinedConstant") != null)
+            setCombinedConstant(Double.parseDouble(props.get("CombinedConstant")));
+        else
+            setCombinedConstant(0.5);
+
         //have to deal with legacy issue by switching from two methods to multiple
         if(props.get("GSEA") != null){
          if((props.get("GSEA")).equalsIgnoreCase("false"))
@@ -469,6 +549,12 @@ public class EnrichmentMapParameters {
      */
     public void copyInputParameters(EnrichmentMapParameters copy){
 
+        //We can only transfer the Network name if it is needed
+        //for instance for Bulk EM creation.
+        if(copy.isBulkEM()){
+            this.NetworkName = copy.getNetworkName();
+            this.BulkEM = copy.isBulkEM();
+        }
         this.GMTFileName = copy.getGMTFileName();
         this.expressionFileName1 = copy.getExpressionFileName1();
         this.expressionFileName2 = copy.getExpressionFileName2();
@@ -506,12 +592,21 @@ public class EnrichmentMapParameters {
         this.Data2 = copy.isData2();
         this.twoDatasets = copy.isTwoDatasets();
         this.method = copy.getMethod();
-        this.jaccard = copy.isJaccard();
+        this.similarityMetric = copy.getSimilarityMetric();
         this.similarityCutOffChanged = copy.similarityCutOffChanged;
 
        //missing the classfiles in the copy --> bug ticket #61
         this.classFile1 = copy.getClassFile1();
         this.classFile2 = copy.getClassFile2();
+
+        //field needed when calculating bulk enrichment maps.
+        this.GMTDirName = copy.getGMTDirName();
+        this.GCTDirName = copy.getGCTDirName();
+        this.GSEAResultsDirName = copy.getGSEAResultsDirName();
+        this.upperlimit = copy.getUpperlimit();
+        this.lowerlimit = copy.getLowerlimit();
+
+
    }
 
 
@@ -559,8 +654,8 @@ public class EnrichmentMapParameters {
         this.twoDatasets = copy.isTwoDatasets();
         this.method = copy.getMethod();
         this.FDR = copy.isFDR();
-        this.jaccard = copy.isJaccard();
-
+        this.similarityMetric = copy.getSimilarityMetric();
+        this.combinedConstant = copy.getCombinedConstant();
         this.similarityCutOffChanged = copy.similarityCutOffChanged;
 
         //copy HashMaps genes and hash2genes
@@ -580,6 +675,7 @@ public class EnrichmentMapParameters {
 
         this.expression = copy.getExpression();
         this.expression2 = copy.getExpression2();
+        this.twoDistinctExpressionSets =  copy.isTwoDistinctExpressionSets();
 
         //missing the classfiles in the copy --> bug ticket #61
         this.classFile1 = copy.getClassFile1();
@@ -598,6 +694,23 @@ public class EnrichmentMapParameters {
 
        this.rank2geneDataset1 = copy.getRank2geneDataset1();
        this.rank2geneDataset2 = copy.getRank2geneDataset2();
+
+
+       //if there are two distinct expression sets we are going to need to instances of few of the variables
+        this.datasetGenes_set2 = copy.getDatasetGenes_set2();
+        this.genesets_set2 = copy.getGenesets_set2();
+        this.filteredGenesets_set2 = copy.getFilteredGenesets_set2();
+        this.genesetsOfInterest_set2 = copy.getGenesetsOfInterest_set2();
+
+
+
+       //field needed when calculating bulk enrichment maps.
+        this.GMTDirName = copy.getGMTDirName();
+        this.GCTDirName = copy.getGCTDirName();
+        this.GSEAResultsDirName = copy.getGSEAResultsDirName();
+        this.upperlimit = copy.getUpperlimit();
+        this.lowerlimit = copy.getLowerlimit();
+
        }
 
    /**
@@ -615,33 +728,47 @@ public class EnrichmentMapParameters {
         String errors = "";
 
         //minimal for either analysis
+        //check to see if GMT is not null but everything else is
+        if(this.enrichmentDataset1FileName1 == null && this.enrichmentDataset1FileName2 == null
+                && this.enrichmentDataset2FileName1 == null && this.enrichmentDataset2FileName2 == null &&
+                this.GMTFileName != null && !this.GMTFileName.equalsIgnoreCase(""))
+            errors = "GMTONLY";
+        else{
 
-        if(this.enrichmentDataset1FileName1.equalsIgnoreCase("") || !checkFile(this.enrichmentDataset1FileName1))
-            errors = errors + "Dataset 1, enrichment file 1 can not be found\n";
-        if(this.twoDatasets){
-            if(this.enrichmentDataset2FileName1.equalsIgnoreCase("") || !checkFile(this.enrichmentDataset2FileName1))
-                errors = errors + "Dataset 2, enrichment file 1 can not be found\n";
-        }
 
-       //GMT file is not required for David analysis
-       if(!this.method.equalsIgnoreCase(EnrichmentMapParameters.method_DAVID))
-            if(this.GMTFileName.equalsIgnoreCase("") || !checkFile(this.GMTFileName))
-                errors = errors + "GMT file can not be found \n";
+            if(this.enrichmentDataset1FileName1 == null || (this.enrichmentDataset1FileName1.equalsIgnoreCase("") || !checkFile(this.enrichmentDataset1FileName1)))
+                errors = errors + "Dataset 1, enrichment file 1 can not be found\n";
+
 
-       // /GSEA inputs
-        if(this.method.equalsIgnoreCase(EnrichmentMapParameters.method_GSEA)){
-            if(this.enrichmentDataset1FileName2.equalsIgnoreCase("") || !checkFile(this.enrichmentDataset1FileName2))
-                errors = errors + "Dataset 1, enrichment file 2 can not be found\n";
             if(this.twoDatasets){
-                if(this.enrichmentDataset2FileName2.equalsIgnoreCase("") || !checkFile(this.enrichmentDataset2FileName2))
-                    errors = errors + "Dataset 2, enrichment file 2 can not be found\n";
+                if(this.enrichmentDataset2FileName1 == null || (this.enrichmentDataset2FileName1.equalsIgnoreCase("") || !checkFile(this.enrichmentDataset2FileName1)))
+                    errors = errors + "Dataset 2, enrichment file 1 can not be found\n";
             }
-        }
 
-        //check to see if there are two datasets if the two gct files are the same
-        if((this.twoDatasets) && (this.expressionFileName1.equalsIgnoreCase(this.expressionFileName2))){
-            this.Data2 = false;
-            this.expressionFileName2 = "";
+            //GMT file is not required for David analysis
+            if(!this.method.equalsIgnoreCase(EnrichmentMapParameters.method_DAVID))
+                if(this.GMTFileName == null || this.GMTFileName.equalsIgnoreCase("") || !checkFile(this.GMTFileName))
+                    errors = errors + "GMT file can not be found \n";
+
+            // /GSEA inputs
+            if(this.method.equalsIgnoreCase(EnrichmentMapParameters.method_GSEA)){
+                if(this.enrichmentDataset1FileName2 != null && (this.enrichmentDataset1FileName2.equalsIgnoreCase("") || !checkFile(this.enrichmentDataset1FileName2)))
+                    errors = errors + "Dataset 1, enrichment file 2 can not be found\n";
+                if(this.twoDatasets){
+                    if(this.enrichmentDataset2FileName2 != null && (this.enrichmentDataset2FileName2.equalsIgnoreCase("") || !checkFile(this.enrichmentDataset2FileName2)))
+                        errors = errors + "Dataset 2, enrichment file 2 can not be found\n";
+                }
+            }
+
+            //check to see if there are two datasets if the two gct files are the same
+            if((this.twoDatasets) && (this.expressionFileName1 != null) && (this.expressionFileName1.equalsIgnoreCase(this.expressionFileName2))){
+                this.Data2 = false;
+                this.expressionFileName2 = "";
+            }
+            //if there are no expression files and this is a david analysis there is no way of telling if they are from the same gmt file so use different one
+            else if((this.expressionFileName1 != null) && (this.expressionFileName2 != null) && this.method.equalsIgnoreCase(EnrichmentMapParameters.method_DAVID)){
+                this.setTwoDistinctExpressionSets(true);
+            }
         }
 
 
@@ -672,6 +799,54 @@ public class EnrichmentMapParameters {
          */
         public void filterGenesets(){
 
+            //check to see if we are dealing with two distinct gene expression files
+            if(this.isTwoDistinctExpressionSets()){
+                //iterate through each geneset and filter each one
+                //have to do it separately for each gene expression set.
+                for(Iterator j = genesets.keySet().iterator(); j.hasNext(); ){
+
+                    String geneset2_name = j.next().toString();
+                    GeneSet current_set =  genesets.get(geneset2_name);
+
+
+                    //compare the HashSet of dataset genes to the HashSet of the current Geneset
+                    //only keep the genes from the geneset that are in the dataset genes
+                    HashSet<Integer> geneset_genes = current_set.getGenes();
+
+                    //Get the intersection between current geneset and dataset genes
+                    Set<Integer> intersection = new HashSet<Integer>(geneset_genes);
+                    intersection.retainAll(datasetGenes);
+
+                    //Add new geneset to the filtered set of genesets
+                    HashSet<Integer> new_geneset = new HashSet<Integer>(intersection);
+                    GeneSet new_set = new GeneSet(geneset2_name,current_set.getDescription());
+                    new_set.setGenes(new_geneset);
+
+                    this.filteredGenesets.put(geneset2_name,new_set);
+                }
+
+                for(Iterator j = genesets_set2.keySet().iterator(); j.hasNext(); ){
+
+                    String geneset2_name = j.next().toString();
+                    GeneSet current_set =  genesets_set2.get(geneset2_name);
+
+                    //compare the HashSet of dataset genes to the HashSet of the current Geneset
+                    //only keep the genes from the geneset that are in the dataset genes
+                    HashSet<Integer> geneset_genes = current_set.getGenes();
+
+                    //Get the intersection between current geneset and dataset genes
+                    Set<Integer> intersection = new HashSet<Integer>(geneset_genes);
+                    intersection.retainAll(datasetGenes_set2);
+
+                    //Add new geneset to the filtered set of genesets
+                    HashSet<Integer> new_geneset = new HashSet<Integer>(intersection);
+                    GeneSet new_set = new GeneSet(geneset2_name,current_set.getDescription());
+                    new_set.setGenes(new_geneset);
+
+                    this.filteredGenesets_set2.put(geneset2_name,new_set);
+                }
+            }
+            else{
             //iterate through each geneset and filter each one
              for(Iterator j = genesets.keySet().iterator(); j.hasNext(); ){
 
@@ -696,6 +871,11 @@ public class EnrichmentMapParameters {
              }
             //once we have filtered the genesets clear the original genesets object
             genesets.clear();
+            genesets_set2.clear();
+
+
+
+            }
 
         }
 
@@ -730,6 +910,8 @@ public class EnrichmentMapParameters {
 
             }
 
+            if(this.getMethod().equalsIgnoreCase(EnrichmentMapParameters.method_DAVID))
+                return true;
             return false;
 
         }
@@ -750,6 +932,7 @@ public class EnrichmentMapParameters {
         paramVariables.append("GMTFileName\t" + GMTFileName + "\n");
         paramVariables.append("expressionFileName1\t" + expressionFileName1 + "\n");
         paramVariables.append("expressionFileName2\t" + expressionFileName2 + "\n");
+        //TODO fix typo in field
         paramVariables.append("enerichmentDataset1FileName1\t" + enrichmentDataset1FileName1 + "\n");//TODO: fix Typo and take care of legacy issue!
         paramVariables.append("enrichmentDataset1FileName2\t" + enrichmentDataset1FileName2 + "\n");
 
@@ -769,21 +952,25 @@ public class EnrichmentMapParameters {
 
         //Write the classes/phenotypes as a comma separated list.
         if(this.isData()){
-            String[] current_pheno = expression.getPhenotypes();
-            if (current_pheno != null){
-                StringBuffer output = new StringBuffer();
-                for(int j = 0; j < current_pheno.length;j++)
-                     output.append(current_pheno[j] + ",");
-                paramVariables.append("class1\t" + output.toString() + "\n");
+            if(expression != null){
+                String[] current_pheno = expression.getPhenotypes();
+                if (current_pheno != null){
+                    StringBuffer output = new StringBuffer();
+                    for(int j = 0; j < current_pheno.length;j++)
+                        output.append(current_pheno[j] + ",");
+                    paramVariables.append("class1\t" + output.toString() + "\n");
+                }
             }
         }
         if(this.isData2()){
-            String[] current_pheno = expression2.getPhenotypes();
-            if (current_pheno != null){
-                StringBuffer output = new StringBuffer();
-                for(int j = 0; j < current_pheno.length;j++)
-                     output.append(current_pheno[j] + ",");
-                paramVariables.append("class2\t" + output.toString() + "\n");
+            if(expression2 != null){
+                String[] current_pheno = expression2.getPhenotypes();
+                if (current_pheno != null){
+                    StringBuffer output = new StringBuffer();
+                    for(int j = 0; j < current_pheno.length;j++)
+                        output.append(current_pheno[j] + ",");
+                    paramVariables.append("class2\t" + output.toString() + "\n");
+                }
             }
         }
 
@@ -796,7 +983,10 @@ public class EnrichmentMapParameters {
 
         //boolean flags
         paramVariables.append("twoDatasets\t" + twoDatasets + "\n");
-        paramVariables.append("jaccard\t" + jaccard + "\n");
+        paramVariables.append("jaccard\t" + similarityMetric + "\n");
+
+        //add the combined constant
+        paramVariables.append("CombinedConstant" + combinedConstant + "\n");
 
         paramVariables.append("Data\t" + Data + "\n");
         paramVariables.append("Data2\t" + Data2 + "\n");
@@ -901,11 +1091,15 @@ public class EnrichmentMapParameters {
                     newMap.put(tokens[0], new GeneSet(tokens));
 
             //Genes
-            if(type == 2)
+            if(type == 2){
             // need to control the Type of the Objects inside the HashMap, otherwise
             // we can't store the List of Genes to new Nodes and Edges in a restored Session
             // e.g. in in the Signature-Post-Analysis
-                newMap.put(tokens[0], Integer.parseInt(tokens[1]));
+                if(tokens.length > 1)
+                    newMap.put(tokens[0], Integer.parseInt(tokens[1]));
+                else
+                    System.out.println(tokens.toString());
+            }
 
             //GseaResult
             if(type == 3)
@@ -923,8 +1117,10 @@ public class EnrichmentMapParameters {
             // need to control the Type of the Objects inside the HashMap, otherwise
             // we can't store the List of Genes to new Nodes and Edges in a restored Session
             // e.g. in in the Signature-Post-Analysis
-                newMap.put(Integer.parseInt(tokens[0]),tokens[1]);
-
+                if(tokens.length > 1)
+                    newMap.put(Integer.parseInt(tokens[0]),tokens[1]);
+                else
+                    System.out.println(tokens.toString());
             }
 
             //Rankings
@@ -973,12 +1169,12 @@ public class EnrichmentMapParameters {
 
     // Class Getters and Setters
 
-    public boolean isJaccard() {
-        return jaccard;
+    public String getSimilarityMetric() {
+        return similarityMetric;
     }
 
-    public void setJaccard(boolean jaccard) {
-        this.jaccard = jaccard;
+    public void setSimilarityMetric(String similarityMetric) {
+        this.similarityMetric = similarityMetric;
     }
 
     public HashMap<String, EnrichmentResult> getEnrichmentResults1() {
@@ -1115,6 +1311,33 @@ public class EnrichmentMapParameters {
 
     }
 
+    public HashMap<String,Integer> getGenesetsGenes(HashMap<String, GeneSet> current_genesets){
+
+        HashMap<String, Integer> genesetGenes = new HashMap<String, Integer>();
+
+        for(Iterator j = current_genesets.keySet().iterator(); j.hasNext(); ){
+
+            String geneset_name = j.next().toString();
+            GeneSet current_set =  current_genesets.get(geneset_name);
+
+            //compare the HashSet of dataset genes to the HashSet of the current Geneset
+            //only keep the genes from the geneset that are in the dataset genes
+            HashSet<Integer> geneset_genes = current_set.getGenes();
+
+            for(Iterator k = geneset_genes.iterator();k.hasNext(); ){
+                Integer current_genekey = (Integer)k.next();
+                //get the current geneName
+                if(hashkey2gene.containsKey(current_genekey)){
+                    String name = hashkey2gene.get(current_genekey);
+                    genesetGenes.put(name, current_genekey);
+                }
+
+            }
+        }
+        return genesetGenes;
+
+    }
+
     public HashMap<String, Integer> getGenes() {
         return genes;
     }
@@ -1176,6 +1399,7 @@ public class EnrichmentMapParameters {
 
     public void noFilter(){
         this.filteredGenesets = genesets;
+        this.filteredGenesets_set2 = genesets_set2;
     }
 
     /**
@@ -1572,5 +1796,99 @@ public class EnrichmentMapParameters {
         this.method = method;
     }
 
+    public boolean isTwoDistinctExpressionSets() {
+        return twoDistinctExpressionSets;
+    }
 
+    public String getGMTDirName() {
+        return GMTDirName;
+    }
+
+    public void setTwoDistinctExpressionSets(boolean twoDistinctExpressionSets) {
+        this.twoDistinctExpressionSets = twoDistinctExpressionSets;
+    }
+
+    public HashSet<Integer> getDatasetGenes_set2() {
+        return datasetGenes_set2;
+    }
+
+    public void setDatasetGenes_set2(HashSet<Integer> datasetGenes_set2) {
+        this.datasetGenes_set2 = datasetGenes_set2;
+    }
+
+    public HashMap<String, GeneSet> getFilteredGenesets_set2() {
+        return filteredGenesets_set2;
+    }
+
+    public void setFilteredGenesets_set2(HashMap<String, GeneSet> filteredGenesets_set2) {
+        this.filteredGenesets_set2 = filteredGenesets_set2;
+    }
+
+    public HashMap<String, GeneSet> getGenesets_set2() {
+        return genesets_set2;
+    }
+
+    public void setGenesets_set2(HashMap<String, GeneSet> genesets_set2) {
+        this.genesets_set2 = genesets_set2;
+    }
+
+    public HashMap<String, GeneSet> getGenesetsOfInterest_set2() {
+        return genesetsOfInterest_set2;
+    }
+
+    public void setGenesetsOfInterest_set2(HashMap<String, GeneSet> genesetsOfInterest_set2) {
+        this.genesetsOfInterest_set2 = genesetsOfInterest_set2;
+    }
+
+    public void setGMTDirName(String GMTDirName) {
+        this.GMTDirName = GMTDirName;
+    }
+
+    public String getGCTDirName() {
+        return GCTDirName;
+    }
+
+    public void setGCTDirName(String GCTDirName) {
+        this.GCTDirName = GCTDirName;
+    }
+
+    public int getLowerlimit() {
+        return lowerlimit;
+    }
+
+    public void setLowerlimit(int lowerlimit) {
+        this.lowerlimit = lowerlimit;
+    }
+
+    public int getUpperlimit() {
+        return upperlimit;
+    }
+
+    public void setUpperlimit(int upperlimit) {
+        this.upperlimit = upperlimit;
+    }
+
+    public String getGSEAResultsDirName() {
+        return GSEAResultsDirName;
+    }
+
+    public void setGSEAResultsDirName(String GSEAResultsDirName) {
+        this.GSEAResultsDirName = GSEAResultsDirName;
+    }
+
+    public double getCombinedConstant() {
+        return combinedConstant;
+    }
+
+    public void setCombinedConstant(double combinedConstant) {
+        this.combinedConstant = combinedConstant;
+    }
+
+    public boolean isBulkEM() {
+        return BulkEM;
+    }
+
+    public void setBulkEM(boolean bulkEM) {
+        BulkEM = bulkEM;
+    }
 }
