@@ -35,11 +35,11 @@
  **
  **/
 
-// $Id: ParametersPanel.java 530 2010-11-29 20:46:10Z risserlin $
-// $LastChangedDate: 2010-11-29 15:46:10 -0500 (Mon, 29 Nov 2010) $
-// $LastChangedRevision: 530 $
+// $Id: ParametersPanel.java 581 2011-07-06 15:47:03Z risserlin $
+// $LastChangedDate: 2011-07-06 11:47:03 -0400 (Wed, 06 Jul 2011) $
+// $LastChangedRevision: 581 $
 // $LastChangedBy: risserlin $
-// $HeadURL: svn+ssh://risserlin@server1.baderlab.med.utoronto.ca/svn/EnrichmentMap/tags/v1.00_cytoscape2.7.0/EnrichmentMapPlugin/src/org/baderlab/csplugins/enrichmentmap/ParametersPanel.java $
+// $HeadURL: svn+ssh://server1.baderlab.med.utoronto.ca/svn/EnrichmentMap/trunk/EnrichmentMapPlugin/src/org/baderlab/csplugins/enrichmentmap/ParametersPanel.java $
 
 package org.baderlab.csplugins.enrichmentmap;
 
@@ -299,13 +299,17 @@ public class ParametersPanel extends JPanel {
            runInfoText = runInfoText + "<b>P-value Cut-off:</b>" + params.getPvalue() + "<br>";
            runInfoText = runInfoText + "<b>FDR Q-value Cut-off:</b>" + params.getQvalue() + "<br>";
 
-           if(params.isJaccard()){
+           if(params.getSimilarityMetric().equalsIgnoreCase(EnrichmentMapParameters.SM_JACCARD)){
                runInfoText = runInfoText + "<b>Jaccard Cut-off:</b>" + params.getSimilarityCutOff() + "<br>";
                runInfoText = runInfoText + "<b>Test used:</b>  Jaccard Index<br>";
            }
-           else{
+           else if(params.getSimilarityMetric().equalsIgnoreCase(EnrichmentMapParameters.SM_OVERLAP)){
                runInfoText = runInfoText + "<b>Overlap Cut-off:</b>" + params.getSimilarityCutOff() + "<br>";
                runInfoText = runInfoText + "<b>Test used:</b>  Overlap Index<br>";
+           }
+            else if(params.getSimilarityMetric().equalsIgnoreCase(EnrichmentMapParameters.SM_COMBINED)){
+               runInfoText = runInfoText + "<b>Jaccard Overlap Combined Cut-off:</b>" + params.getSimilarityCutOff() + "<br>";
+               runInfoText = runInfoText + "<b>Test used:</b>  Jaccard Overlap Combined Index (k constant = " + params.getCombinedConstant() + ")<br>";
            }
            runInfoText = runInfoText + "<font size=-1><b>Genesets File:</b>" + shortenPathname(params.getGMTFileName()) + "<br>";
            runInfoText = runInfoText + "<b>Dataset 1 Data Files:</b> " + shortenPathname(params.getEnrichmentDataset1FileName1()) + ",<br>" + shortenPathname(params.getEnrichmentDataset1FileName2()) + "<br>";
@@ -315,7 +319,7 @@ public class ParametersPanel extends JPanel {
            if(params.isData()){
                runInfoText = runInfoText + "<b>Data file:</b>" + shortenPathname(params.getExpressionFileName1()) + "<br>";
            }
-           if(params.isData2()){
+           if(params.isData2() && params.getExpression2() != null){
                runInfoText = runInfoText + "<b>Data file 2:</b>" + shortenPathname(params.getExpressionFileName2()) + "<br>";
            }
            if( ! (params.getGseaHtmlReportFileDataset1() == null) ){
