@@ -35,11 +35,11 @@
  **
  **/
 
-// $Id: VisualizeEnrichmentMapTask.java 492 2010-04-01 16:05:34Z revilo $
-// $LastChangedDate: 2010-04-01 12:05:34 -0400 (Thu, 01 Apr 2010) $
-// $LastChangedRevision: 492 $
-// $LastChangedBy: revilo $
-// $HeadURL: svn+ssh://risserlin@server1.baderlab.med.utoronto.ca/svn/EnrichmentMap/trunk/EnrichmentMapPlugin/src/org/baderlab/csplugins/enrichmentmap/VisualizeEnrichmentMapTask.java $
+// $Id: VisualizeEnrichmentMapTask.java 583 2011-07-06 18:41:57Z risserlin $
+// $LastChangedDate: 2011-07-06 14:41:57 -0400 (Wed, 06 Jul 2011) $
+// $LastChangedRevision: 583 $
+// $LastChangedBy: risserlin $
+// $HeadURL: svn+ssh://server1.baderlab.med.utoronto.ca/svn/EnrichmentMap/trunk/EnrichmentMapPlugin/src/org/baderlab/csplugins/enrichmentmap/VisualizeEnrichmentMapTask.java $
 
 package org.baderlab.csplugins.enrichmentmap;
 import cytoscape.task.Task;
@@ -126,40 +126,72 @@ public class VisualizeEnrichmentMapTask implements Task {
             CyNetwork network;
             String prefix;
 
-            //There are no networks then create a new one.
-            if(networks == null){
-                //create the network
+            //Check to see if there is already a name specifed for the network
+            //We still need to calculate the number of networks so that we can specify the paramters for
+            //each network.
+            if(params.getNetworkName() != null){
+               network = Cytoscape.createNetwork(params.getNetworkName());
+               if(networks == null)
+                    prefix = "EM1";
+               else{
+                //how many enrichment maps are there?
+                    int num_networks = 1;
+                    int max_prefix = 0;
+                    EnrichmentMapManager manager = EnrichmentMapManager.getInstance();
+                    for(Iterator<CyNetwork> i = networks.iterator(); i.hasNext();){
+                        CyNetwork current_network = i.next();
+                        String networkId = current_network.getIdentifier();
+                        if( manager.isEnrichmentMap(networkId) ) {//fails
+                            num_networks++;
+                            EnrichmentMapParameters tmpParams = manager.getParameters(networkId);
+                            String tmpPrefix = tmpParams.getAttributePrefix();
+                            tmpPrefix = tmpPrefix.replace("EM", "");
+                            tmpPrefix = tmpPrefix.replace("_", "");
+                            int tmpNum = Integer.parseInt(tmpPrefix);
+                            if (tmpNum > max_prefix)
+                                max_prefix = tmpNum;
+                        }
+                    }
+                    prefix = "EM" + (max_prefix + 1) + "_";
+               }
+               params.setAttributePrefix(prefix);
 
-                prefix = "EM1_";
-                params.setAttributePrefix(prefix);
-                params.setNetworkName(prefix+mapName);
-                network = Cytoscape.createNetwork(prefix + mapName);
             }
             else{
-                //how many enrichment maps are there?
-                int num_networks = 1;
-                int max_prefix = 0;
-                EnrichmentMapManager manager = EnrichmentMapManager.getInstance();
-                for(Iterator<CyNetwork> i = networks.iterator(); i.hasNext();){
-                    CyNetwork current_network = i.next();
-                    String networkId = current_network.getIdentifier();
-                    if( manager.isEnrichmentMap(networkId) ) {//fails
-                        num_networks++;
-                        EnrichmentMapParameters tmpParams = manager.getParameters(networkId);
-                        String tmpPrefix = tmpParams.getAttributePrefix();
-                        tmpPrefix = tmpPrefix.replace("EM", "");
-                        tmpPrefix = tmpPrefix.replace("_", "");
-                        int tmpNum = Integer.parseInt(tmpPrefix);
-                        if (tmpNum > max_prefix)
-                            max_prefix = tmpNum;
-                    }
-                }
-                prefix = "EM" + (max_prefix + 1) + "_";
-                params.setAttributePrefix(prefix);
-                params.setNetworkName(prefix+mapName);
-                network = Cytoscape.createNetwork(prefix + mapName);
-            }
+                //There are no networks then create a new one.
+                if(networks == null){
+                    //create the network
 
+                    prefix = "EM1_";
+                    params.setAttributePrefix(prefix);
+                    params.setNetworkName(prefix+mapName);
+                    network = Cytoscape.createNetwork(prefix + mapName);
+                }
+                else{
+                    //how many enrichment maps are there?
+                    int num_networks = 1;
+                    int max_prefix = 0;
+                    EnrichmentMapManager manager = EnrichmentMapManager.getInstance();
+                    for(Iterator<CyNetwork> i = networks.iterator(); i.hasNext();){
+                        CyNetwork current_network = i.next();
+                        String networkId = current_network.getIdentifier();
+                        if( manager.isEnrichmentMap(networkId) ) {//fails
+                            num_networks++;
+                            EnrichmentMapParameters tmpParams = manager.getParameters(networkId);
+                            String tmpPrefix = tmpParams.getAttributePrefix();
+                            tmpPrefix = tmpPrefix.replace("EM", "");
+                            tmpPrefix = tmpPrefix.replace("_", "");
+                            int tmpNum = Integer.parseInt(tmpPrefix);
+                            if (tmpNum > max_prefix)
+                                max_prefix = tmpNum;
+                        }
+                    }
+                    prefix = "EM" + (max_prefix + 1) + "_";
+                    params.setAttributePrefix(prefix);
+                    params.setNetworkName(prefix+mapName);
+                    network = Cytoscape.createNetwork(prefix + mapName);
+                }
+            }
             // store path to GSEA report in Network Attribute
             if (params.getMethod().equalsIgnoreCase(EnrichmentMapParameters.method_GSEA)) {
                 CyAttributes networkAttributes = Cytoscape
@@ -198,6 +230,7 @@ public class VisualizeEnrichmentMapTask implements Task {
             HashMap<String, EnrichmentResult> enrichmentResults2 = params.getEnrichmentResults2();
 
             HashMap<String, GeneSet> genesetsOfInterest = params.getGenesetsOfInterest();
+            HashMap<String, GeneSet> genesetsOfInterest_set2 = params.getGenesetsOfInterest_set2();
 
             int currentProgress = 0;
             int maxValue = enrichmentResults1OfInterest.size();
@@ -220,7 +253,19 @@ public class VisualizeEnrichmentMapTask implements Task {
                 network.addNode(node);
 
                 //Add the description to the node
-                GeneSet gs = (GeneSet)genesetsOfInterest.get(current_name);
+                GeneSet gs = null;
+                GeneSet gs2 = null;
+                if(!params.isTwoDistinctExpressionSets())
+                    gs = (GeneSet)genesetsOfInterest.get(current_name);
+                else{
+                    if(genesetsOfInterest.containsKey(current_name))
+                        gs = (GeneSet)genesetsOfInterest.get(current_name);
+                    if(genesetsOfInterest_set2.containsKey(current_name))
+                        gs2 = (GeneSet)genesetsOfInterest_set2.get(current_name);
+
+                    if(gs == null && gs2 != null)
+                        gs = gs2;
+                }
                 CyAttributes nodeAttrs = Cytoscape.getNodeAttributes();
                 nodeAttrs.setAttribute(node.getIdentifier(), prefix+ EnrichmentMapVisualStyle.GS_DESCR, gs.getDescription());
 
@@ -228,7 +273,13 @@ public class VisualizeEnrichmentMapTask implements Task {
                 //only create the list if the hashkey 2 genes is not null Otherwise it take too much time to populate the list
                 if(params.getHashkey2gene() != null){
                     List<String> gene_list = new ArrayList<String>();
-                    HashSet<Integer> genes_hash = gs.getGenes();
+                    HashSet<Integer> genes_hash = new HashSet<Integer>();
+
+                    genes_hash.addAll(gs.getGenes());
+
+                    if(gs2 != null)
+                        genes_hash.addAll(gs2.getGenes());
+
                     for(Iterator<Integer> j=genes_hash.iterator(); j.hasNext();){
                         Integer current = j.next();
                         String gene = params.getGeneFromHashKey(current);
@@ -298,7 +349,19 @@ public class VisualizeEnrichmentMapTask implements Task {
                         network.addNode(node);
 
                         //Add the description to the node
-                        GeneSet gs = (GeneSet)genesetsOfInterest.get(current_name);
+                        GeneSet gs =null;
+                        GeneSet gs2 = null;
+                        if(!params.isTwoDistinctExpressionSets())
+                            gs = (GeneSet)genesetsOfInterest.get(current_name);
+                        else{
+                            if(genesetsOfInterest.containsKey(current_name))
+                                gs = (GeneSet)genesetsOfInterest.get(current_name);
+                            if(genesetsOfInterest_set2.containsKey(current_name))
+                                gs2 = (GeneSet)genesetsOfInterest_set2.get(current_name);
+
+                            if(gs == null && gs2 != null)
+                                gs = gs2;
+                        }
                         CyAttributes nodeAttrs = Cytoscape.getNodeAttributes();
                         nodeAttrs.setAttribute(node.getIdentifier(), prefix+ EnrichmentMapVisualStyle.GS_DESCR, gs.getDescription());
 
@@ -306,7 +369,12 @@ public class VisualizeEnrichmentMapTask implements Task {
                         //only create the list if the hashkey 2 genes is not null Otherwise it take too much time to populate the list
                         if(params.getHashkey2gene() != null){
                             List<String> gene_list = new ArrayList<String>();
-                            HashSet<Integer> genes_hash = gs.getGenes();
+                            HashSet<Integer> genes_hash = new HashSet<Integer>();
+                            genes_hash.addAll(gs.getGenes());
+
+                            if(gs2 != null)
+                                genes_hash.addAll(gs2.getGenes());
+
                             for(Iterator<Integer> j=genes_hash.iterator(); j.hasNext();){
                                 Integer current = j.next();
                                 String gene = params.getGeneFromHashKey(current);
@@ -344,11 +412,22 @@ public class VisualizeEnrichmentMapTask implements Task {
                 String current_name =j.next().toString();
                 GenesetSimilarity current_result = geneset_similarities.get(current_name);
 
+
                 //only create edges where the jaccard coefficient to great than
-                if(current_result.getSimilarity_coeffecient()>params.getSimilarityCutOff()){
+                if(current_result.getSimilarity_coeffecient()>=params.getSimilarityCutOff()){
                     Node node1 = Cytoscape.getCyNode(current_result.getGeneset1_Name(),false);
                     Node node2 = Cytoscape.getCyNode(current_result.getGeneset2_Name(),false);
-                    Edge edge = (Edge) Cytoscape.getCyEdge(node1, node2, Semantics.INTERACTION, EnrichmentMapParameters.ENRICHMENT_INTERACTION_TYPE, true);
+
+                    Edge edge;
+
+                    //in order to create multiple edges we need to create different edge types between the same two nodes
+                    if(current_result.getEnrichment_set() == 1)
+                        edge = (Edge) Cytoscape.getCyEdge(node1,  node2, Semantics.INTERACTION,EnrichmentMapParameters.ENRICHMENT_INTERACTION_TYPE_SET1, true);
+                    else if(current_result.getEnrichment_set() == 2)
+                        edge = (Edge) Cytoscape.getCyEdge(node1,  node2, Semantics.INTERACTION,EnrichmentMapParameters.ENRICHMENT_INTERACTION_TYPE_SET2,true);
+                    else
+                        edge = (Edge) Cytoscape.getCyEdge(node1,  node2, Semantics.INTERACTION,EnrichmentMapParameters.ENRICHMENT_INTERACTION_TYPE,true);
+
 
                     network.addEdge(edge);
 
@@ -357,6 +436,7 @@ public class VisualizeEnrichmentMapTask implements Task {
                     CyAttributes edgeAttrs = Cytoscape.getEdgeAttributes();
                     edgeAttrs.setAttribute(edge.getIdentifier(), prefix+EnrichmentMapVisualStyle.SIMILARITY_COEFFECIENT, current_result.getSimilarity_coeffecient());
                     edgeAttrs.setAttribute(edge.getIdentifier(), prefix+ EnrichmentMapVisualStyle.OVERLAP_SIZE, current_result.getSizeOfOverlap());
+                    edgeAttrs.setAttribute(edge.getIdentifier(), prefix + EnrichmentMapVisualStyle.ENRICHMENT_SET  , current_result.getEnrichment_set());
 
                     //create an attribute that stores the genes that are associated with this edge as an attribute list
                     //only create the list if the hashkey 2 genes is not null Otherwise it take too much time to populate the list
@@ -432,7 +512,7 @@ public class VisualizeEnrichmentMapTask implements Task {
 
 
         } catch(IllegalThreadStateException e){
-            taskMonitor.setException(e, "Unable to compute similarity coeffecients");
+            taskMonitor.setException(e, "Unable to compute similarity coefficients");
             return false;
         }
 
